summaryrefslogtreecommitdiffstats
path: root/kmail/imapaccountbase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
commitf4fae92b6768541e2952173c3d4b09040f95bf7e (patch)
treed8c5d93232235cd635f3310b4d95490df181ba2d /kmail/imapaccountbase.h
parent125c0a08265b75a133644d3b55f47e37c919f45d (diff)
downloadtdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.tar.gz
tdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.zip
Moved kpilot from kdepim to applications, as the core Trinity libraries should not contain hardware-dependent software
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/imapaccountbase.h')
-rw-r--r--kmail/imapaccountbase.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/imapaccountbase.h b/kmail/imapaccountbase.h
index 39fb33b6..0795eb2a 100644
--- a/kmail/imapaccountbase.h
+++ b/kmail/imapaccountbase.h
@@ -266,9 +266,9 @@ namespace KMail {
/**
* Called when we're completely done checking mail for this account
* When @p setStatusMsg is true a status msg is shown
*/
- void postProcessNewMail( bool setStatusMsg = true );
+ void postProcessNewMail( bool seStatusMsg = true );
/**
* Check whether we're checking for new mail
@@ -397,7 +397,7 @@ namespace KMail {
* Returns true if the account has the given capability
*/
bool hasCapability( const TQString& capa ) {
- return mCapabilities.contains( capa ); }
+ return mCapabilities.tqcontains( capa ); }
/**
* Create an IMAP path for a parent folder and a foldername
@@ -437,7 +437,7 @@ namespace KMail {
/**
* Only delete information about the job and ignore write errors
*/
- void slotSetStatusResult(KIO::Job * job);
+ void slotSeStatusResult(KIO::Job * job);
/// Result of getUserRights() job
void slotGetUserRightsResult( KIO::Job* _job );
@@ -590,7 +590,7 @@ namespace KMail {
/**
* Emitted when changeSubscription() failed.
* @param errorMessage the error message that contains the reason for the failure
*/
void subscriptionChangeFailed( const TQString &errorMessage );
@@ -266,9 +266,9 @@ namespace KMail {
/**
* Called when we're completely done checking mail for this account
- * When @p setStatusMsg is true a status msg is shown
+ * When @p seStatusMsg is true a status msg is shown
*/
@@ -590,7 +590,7 @@ namespace KMail {
/**
* Emitted when changeSubscription() failed.
- * @param errorMessage the error message that contains the reason for the failure
+ * @param errorMessage the error message that tqcontains the reason for the failure
*/
void subscriptionChangeFailed( const TQString &errorMessage );